Skip to contents

Visualize boundary uncertain locations

Usage

plot_boundary(
  dat_loc,
  cluster,
  is_uncertain,
  is_boundary,
  title = "Boundary",
  color_mode = c("status", "cluster"),
  palette = NULL,
  point_size = 1.45,
  boundary_size = 1.5,
  point_alpha = 1,
  legend_position = "bottom",
  strip_text_size = 16,
  legend_text_size = 12,
  legend_title_size = 12,
  ...
)

Arguments

dat_loc

A numeric matrix of dimension \(n \times \rho\), where \(n\) is the number of observations and \(\rho = 2\) corresponds to two spatial coordinates.

cluster

A vector of length \(n\) giving cluster labels.

is_uncertain

A logical vector of length \(n\).

is_boundary

A logical vector of length \(n\), or a vector of indices of boundary locations.

title

A character string specifying the facet title.

color_mode

A character string specifying the coloring mode. Must be one of "status" or "cluster". If "status", points are colored as certain / uncertain / boundary. If "cluster", points are colored by cluster label and boundary locations are highlighted with a larger outline.

palette

An optional character vector of colors for cluster labels when color_mode = "cluster".

point_size

A numeric value specifying the point size for background points.

boundary_size

A numeric value specifying the point size for boundary points.

point_alpha

A numeric value specifying the point alpha.

legend_position

A character string specifying the legend position.

strip_text_size

A numeric value specifying the facet strip text size.

legend_text_size

A numeric value specifying the legend text size.

legend_title_size

A numeric value specifying the legend title size.

...

Additional arguments passed to ggplot2::geom_point().

Value

A ggplot object.