Skip to contents

QUEST is a computational method for quantifying uncertainty in spatial domain detection for spatial transcriptomics. By leveraging fuzzy clustering, QUEST generates probabilistic domain assignments and location-level uncertainty estimates, enabling the separation of confidently assigned locations from ambiguous ones. Building on this uncertainty quantification framework, QUEST facilitates the identification of novel tissue structures, including transitional boundaries and heterogeneous subdomains, improves the accuracy of downstream analyses by prioritizing high-confidence locations, and helps guide the determination of the number of spatial domains.

Author

Maintainer: Yanlin Tong zoetong@umich.edu

Authors:

  • Xiang Zhou

Other contributors:

  • Xiaoquan Wen [contributor]

  • Jiandie Lin [contributor]