Visualize aggregated uncertain locations
Usage
plot_aggregation(
dat_loc,
cluster,
is_uncertain,
is_aggre,
igraph_cluster = NULL,
title = "Aggregation",
color_mode = c("status", "cluster", "igraph"),
palette = NULL,
point_size = 1.5,
aggre_size = 2.2,
point_alpha = 1,
legend_position = "bottom",
strip_text_size = 16,
legend_text_size = 12,
legend_title_size = 12,
background_color = "grey85",
...
)Arguments
- dat_loc
A numeric matrix of dimension \(n \times \rho\), where \(n\) is the number of observations and \(\rho = 2\) corresponds to two spatial coordinates.
- cluster
A vector of length \(n\) giving cluster labels.
- is_uncertain
A logical vector of length \(n\).
- is_aggre
A logical vector of length \(n\), or a vector of indices of aggregated locations.
- igraph_cluster
An optional vector of connected-component labels of length \(n\). Non-aggregated locations can be
NA. Ifcolor_mode = "igraph", only aggregated locations are displayed.- title
A character string specifying the facet title.
- color_mode
A character string specifying the coloring mode. Must be one of
"status","cluster", or"igraph".- palette
An optional character vector of colors for cluster or igraph labels.
- point_size
A numeric value specifying the point size for background points.
- aggre_size
A numeric value specifying the point size for aggregated points when highlighted.
- point_alpha
A numeric value specifying the point alpha.
- legend_position
A character string specifying the legend position.
- strip_text_size
A numeric value specifying the facet strip text size.
- legend_text_size
A numeric value specifying the legend text size.
- legend_title_size
A numeric value specifying the legend title size.
- ...
Additional arguments passed to
ggplot2::geom_point().