Uncertainty can be displayed either as a continuous variable or as categorized levels based on mean and standard deviation thresholds.
Usage
plot_uncertainty(
dat_loc,
uncertainty,
mode = c("continuous", "category"),
title = "Uncertainty",
point_size = 1.45,
point_alpha = 1,
tile_alpha = 1,
add_tile = TRUE,
relabel = TRUE,
legend_position = "bottom",
strip_text_size = 16,
legend_text_size = 12,
legend_title_size = 12,
legend_nrow = 4,
...
)Arguments
- dat_loc
A numeric matrix of dimension \(n \times \rho\), where \(n\) is the number of observations and \(\rho = 2\) corresponds to two spatial coordinates.
- uncertainty
A numeric vector of length \(n\) giving uncertainty values.
- mode
A character string specifying the visualization mode. Must be one of
"continuous"or"category".- title
A character string specifying the facet title.
- point_size
A numeric value specifying the point size.
- point_alpha
A numeric value specifying the point alpha.
- tile_alpha
A numeric value specifying the tile alpha.
- add_tile
A logical value indicating whether to add
geom_tile().- relabel
A logical value indicating whether to relabel category levels as "Certain", "Uncertain (moderate)", "Uncertain (high)", and "Uncertain (extreme)" when
mode = "category".- legend_position
A character string specifying the legend position.
- strip_text_size
A numeric value specifying the facet strip text size.
- legend_text_size
A numeric value specifying the legend text size.
- legend_title_size
A numeric value specifying the legend title size.
- legend_nrow
An integer specifying the number of rows in the legend when
mode = "category".- ...
Additional arguments passed to
ggplot2::geom_point().